Math package
============

Submodules
----------

Math.Complex module
-------------------

.. automodule:: Math.Complex
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: Math
   :members:
   :undoc-members:
   :show-inheritance:
